# -*- coding: utf-8 -*-
"""
author: zengbin93
email: zeng_bin8888@163.com
create_dt: 2021/9/25 13:38
describe: 摘录一些缠中说禅良言警句，希望能帮助更多人走出来。
"""
import random

texts = {
    "1": "一定要注意，你不是多头也不是空头，但你一定要知道一旦发生什么情况，多头会干什么，空头会干什么。\n"
         "例如，多头的愿望肯定是想补上面的缺口，这就构成市场的一个潜在力量，这个力量，在其他力量的干扰下，\n"
         "可能一时发挥不出来，但这反而构成我们一个更好的买入点。请好好品味这句话：你不当多头也不当空头，\n"
         "但一定要知道空头多头想干什么，而走势是最终的结果，他们想干的是否干出来了，这才是关键。干不出来，\n"
         "有什么后果，他们会有什么后续的步骤，这才是该想的东西。\n"
         "\n--摘自《2008-01-29 15:19 年线支持初显现》",

    "2": "要战胜市场，首先要了解市场的众生。市场是合力的，而合这力的不是机械，而是活生生的人。市场中，最多数的，\n"
         "都是糊涂蛋，赚钱了不知道为什么，亏钱了不知道为什么，最后变青蛙了，也会说，井上面的天空好大，好复杂，\n"
         "怎么处理啊？哪里有拐杖啊？几乎绝大多数的人，进市场来时，根本不知道市场是什么，然后就不断投入，最后有些\n"
         "输红眼了，砸锅卖铁也就进来了。对于市场，本ID有一个观点，大概有点过分，但确实是对的。市场，就是要0投入去赚钱。\n"
         "\n--摘自《2008-01-22 16:10 教你炒股票95：修炼自己》",

    "3": "要认清市场，首先要认清自己，知道自己的弱点在哪里，自己在市场中的每个行为，都要清楚地意识到。\n"
         "每天收盘后，都找十分钟，把自己当天的操作以及看盘时的心理过程复一次盘，这是十分必要的。\n"
         "\n--摘自《2007-04-04 15:31 教你炒股票42：有些人是不适合参与市场的》",

    "4": "今天该股90%多的换手意味着，所有中签的人基本都抛了（对手盘包括其中），而且绝大多数都在10几元抛的。\n"
         "这就对了，你们10几元不看好，有人要看好，市场向所有人开着，凭什么不能买？市场就是一个斗心理的过程，\n"
         "大家都想一块去了，大家还用不用活了？\n"
         "\n--摘自《2006-06-19 16:45 鄙视所有对N中工15元不敢买50元就吃醋的人！》",

    "5": "你的喜好，就是你的死亡陷阱！在市场中要生存，第一条就是在市场中要杜绝一切喜好。市场的诱惑，永远就是\n"
         "通过你的喜好而陷你于死亡。市场中需要的是露水之缘而不是比翼之情，天长地久之类的东西和市场无关。市场\n"
         "中唯一值得天长地久的就是赢钱，任何一个来市场的人，其目的就是赢钱，任何与赢钱无关的都是废话。必须明\n"
         "白，任何让你买入一只股票的理由，并不是因为这股票如何好或被忽悠得如何好，只是你企图通过买入而赢钱，\n"
         "能赢钱的股票就是好的，否则都是废话。因此，市场中的任何喜好，都是把你引入迷途的陷阱，必须逐一看破，\n"
         "进而洗心革面，才能在市场上生存。\n"
         "\n--摘自《2006-06-09 17:03 教你炒股票3：你的喜好，你的死亡陷阱！》",

    "6": "能看清楚自己周围的市场陷阱，还只是第一步，更进一步，要学会利用市场陷阱来赢钱。当你要买的时候，\n"
         "空头的陷阱就是你的最佳机会，当你要卖的时候，多头的陷阱当然就是你的天堂。这市场，永远不缺卖在最低点，\n"
         "买在最高点的人，这世界上没有什么是可以让所有人赢钱的，连大牛市中都有很多人要亏损累累。\n"
         "而市场中的行为，就如同一个修炼上乘武功的过程，最终能否成功，还是要落实到每个人的智慧、秉性、天赋、勤奋上来！\n"
         "\n--摘自《2006-06-09 17:03 教你炒股票3：你的喜好，你的死亡陷阱！》",

    "7": "市场是有规律的，但市场的规律并不是显而易见的，是需要严格的分析才能得到。更重要的是，\n"
         "市场的规律是一种动态的，在不同级别合力作用下显示出来的规律，企图用些单纯的指标、波段、\n"
         "波浪、分型、周期等等预测、把握，只可能错陋百出。但只要把这动态的规律在当下的直观中把握\n"
         "好、应用纯熟，踏准市场的节奏，并不是不可能的。\n"
         "\n--摘自《2006-12-27 15:18 教你炒股票19：学习缠中说禅技术分析理论的关键》",

    "8": "战胜市场，其实就是战胜自己的贪婪、恐惧、愚蠢，本ID的理论只是把市场拔光给各位看，而拔光\n"
         "一个人并不意味着就等于征服一个人，对于市场，其道理是一样的。不干，不可能征服市场。对于\n"
         "市场来说，干就是一切。技术分析的最终意义不是去预测市场要干什么，而是市场正在干什么，是\n"
         "一种当下的直观。在市场上所有的错误都是离开了这当下的直观，用想象、用情绪来代替。\n"
         "\n--摘自《2006-12-27 15:18 教你炒股票19：学习缠中说禅技术分析理论的关键》",

    "9": "熟悉本ID所解《论语》的都知道，风险是“不患”的，是无位次的，任何妄求在投资中的绝对无风险\n"
         "，都是痴心妄想。唯一的办法，就是设置一个系统，使得无位次、“不患”的风险在该系统中成为有\n"
         "位次，“患”的系统，这是长期战胜市场的唯一方法。\n"
         "\n--摘自《2006-12-01 12:03 教你炒股票12：一吻何能消魂？》",
}

def print_one():
    k = random.randint(1, 9)
    print(f"缠中说禅醒世良言：\n{k}", texts[str(k)])
